/*
 * FileWatcherOptionPane.java - Part of the FileWatcher plugin for jEdit.
 * Copyright (C) 1999 Ollie Rutherfurd
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.border.*;

import org.gjt.sp.jedit.*;
import org.gjt.sp.jedit.gui.*;

/**
* @author Ollie Rutherfurd <a href="mailto:oliver@rutherfurd.net">Ollie Rutherfurd</a>
*/
public class FileWatcherOptionPane extends org.gjt.sp.jedit.AbstractOptionPane {

	private JCheckBox watchCurrentBuffer;
	private JCheckBox beepOnAutoLoad;
	private JComboBox reloadAction;

	public FileWatcherOptionPane(){
		super("filewatcher");

		watchCurrentBuffer = new JCheckBox("Watch current buffer");
		addComponent(watchCurrentBuffer);
		
		beepOnAutoLoad = new JCheckBox("Beep on auto-reload");
		addComponent(beepOnAutoLoad);

		JPanel reloadPanel = new JPanel();
		reloadPanel.setLayout(new FlowLayout());
		reloadPanel.add(new JLabel("When change is detected: "));
		reloadAction = new JComboBox(new String[] { "prompt", "auto-reload", "nothing"} );
		reloadPanel.add(reloadAction);
		addComponent(reloadPanel);

		load();
	}

	public void load(){
		watchCurrentBuffer.setSelected(getBooleanProperty("filewatcher.watch-current-buffer", false));
		beepOnAutoLoad.setSelected(getBooleanProperty("filewatcher.beep-on-auto-load", true));
		reloadAction.setSelectedItem(getReloadActionProperty("filewatcher.reload-action", "prompt"));
	}

	public static String getReloadActionProperty(String prop, String defaultValue){
		String action = jEdit.getProperty(prop);
		if(action == null) action = defaultValue;
		action = action.toLowerCase();
		if(!	(action.equals("prompt") || 
				action.equals("auto-reload") ||
				action.equals("nothing")))

		action = defaultValue;
		return action;
	}

	/**
	* Called when the options dialog's `OK' button is pressed.
	* This should save any properties saved in this option pane.
	*/
	public void save() {
		jEdit.setProperty("filewatcher.beep-on-auto-load", beepOnAutoLoad.isSelected() ? "1" : "0");
		jEdit.setProperty("filewatcher.reload-action", reloadAction.getSelectedItem().toString().toLowerCase());
		jEdit.setProperty("filewatcher.watch-current-buffer", watchCurrentBuffer.isSelected() ? "1" : "0");
	}


	public static boolean getBooleanProperty(String prop, boolean defaultVal) {
		String value = jEdit.getProperty(prop);
		if(value != null) {
			value = value.toLowerCase();

			if(value.equals("1")) return true;
			else if(value.equals("on")) return true;
			else if(value.startsWith("t")) return true;
			else if(value.equals("0")) return false;
			else if(value.equals("off")) return false;
			else if(value.startsWith("f")) return false;
		}
		return defaultVal;
	}

}
