/*
 * PromptForFileReload.java - Part of the FileWatcher plugin for jEdit.
 * Copyright (C) 1999 Ollie Rutherfurd
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

import javax.swing.*;
import java.util.*;
import java.text.SimpleDateFormat;

import org.gjt.sp.jedit.*;
import org.gjt.sp.util.Log;


/**
*	@author Ollie Rutherfurd <a href="mailto:oliver@rutherfurd.net">Ollie Rutherfurd</a>
*/
public class PromptForFileReload implements Runnable{

	private View view;
	private String filename;
	private WatchList watchList;

	public PromptForFileReload(View view, String filename, WatchList watchList){
		this.view = view;
		this.filename = filename;
		this.watchList = watchList;
	}

	public void run(){

		try{
			// last modified date on disk
			Date saveDate = new Date(watchList.getLastModifiedTime(filename));
			// last saved in jEdit
			Date watchDate = new Date(watchList.getTime(filename));

			// formatting for file dates
			SimpleDateFormat df = new java.text.SimpleDateFormat("MM.dd.yyyy - HH:mm:ss");

			// update before showing dialog
			watchList.updateTimeFromFile(filename);

			int result = JOptionPane.showConfirmDialog(view,
								"Reload file modified since last save in jEdit?\n\n" +
									"File: " + filename + "\n" +
									"Saved in jEdit: " + df.format(watchDate) + "\n" + 
									"Last modified:  " + df.format(saveDate),
								"File Modified Outside jEdit",
								JOptionPane.YES_NO_OPTION,
								JOptionPane.INFORMATION_MESSAGE);

			if(result == JOptionPane.YES_OPTION){
				// System.out.println("FileWatcher.PromptForReload reloading: " + filename);	// ##
				view.saveCaretInfo();
				view.getBuffer().load(view);
				view.loadCaretInfo();
				view.focusOnTextArea();
				Log.log(Log.NOTICE, this, "Accepted Reload Completed -> " + filename);
			}
			else{
				Log.log(Log.NOTICE, this, "Reload Declined -> " + filename);
			}

		}catch(Exception e){
			Log.log(Log.ERROR, this, e.toString());
		}
	}
}
