/*
 * WatchList.java - Part of the FileWatcher plugin for jEdit.
 * Copyright (C) 1999 Ollie Rutherfurd
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */


import java.io.*;
import java.util.*;


/**
*	@author Ollie Rutherfurd <a href="mailto:oliver@rutherfurd.net">Ollie Rutherfurd</a>
*/
public class WatchList{

	/** Hashtable for storing file names and 'lave save' times */
	private Hashtable fileList;


	/**
	* Default constructor.
	*/
	public WatchList(){
		fileList = new Hashtable();
	}


	/**
	* Adds a file to the list.
	*/
	public void add(String filename){
		fileList.put(filename, new Long((new File(filename)).lastModified()));
	}


	/**
	* Updates the stored 'last save' time with <code>newTime</code>
	*/
	public void updateTime(String filename, long newTime){
		fileList.put(filename, new Long(newTime));
	}


	/**
	* Updates the stored 'last save' time for the file from the file's lastModifiedTime.
	*/
	public void updateTimeFromFile(String filename){
		try{
			File file = new File(filename);
			fileList.put(filename, new Long(file.lastModified()));
		}catch(Exception e){
			System.err.println("WatchList.updateTimeFromFile (" + filename + "): " + e);
		}
	}


	/**
	* Returns the stored time of the last time the file was saved in jEdit (or the user was prompted for a reload)
	*/
	public long getTime(String filename){
		long rValue = 0;
		try{
			rValue = ((Long) fileList.get(filename)).longValue();
		}catch(Exception e){
			System.err.println("WatchList.getTime (" + filename + "): " + e);
		}
		return rValue;
	}


	/**
	* Returns the file's lastModified time.
	*/
	public long getLastModifiedTime(String filename){
		try{
			File file = new File(filename);
			return file.lastModified();
		}catch(Exception e){
			System.err.println("WatchList.getLastModifiedTime (" + filename + "): " + e);
		}
		return 0;
	}


	/**
	* Removes <code>filename</code> from the list.
	*/
	public void remove(String filename){
		fileList.remove(filename);
	}


	/**
	* Returns the number of entries.
	*/
	public int size(){ return fileList.size(); }
}
